import{cL as d}from"./outputWidgets.75a5b0b9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="033433d4-7974-470f-ae33-eee9654d7567",e._sentryDebugIdIdentifier="sentry-dbid-033433d4-7974-470f-ae33-eee9654d7567")}catch{}})();const t=(e,r)=>{d.error({message:e,description:r})};export{t as p};
//# sourceMappingURL=popupNotifcation.9f86b194.js.map
