import{_ as B}from"./logo.084e5d7c.js";import{x as C,b as s,et as y,eD as I,eE as w,e as h,d as k,ez as L,a as N,u as e,c,bN as D,w as t,f as o,aT as d,eC as _,c9 as m,cN as S,t as T,eB as V,eZ as E,bq as R,ew as P}from"./outputWidgets.75a5b0b9.js";import{a as b}from"./console.3fb52eaf.js";import{a as $}from"./asyncComputed.c701d7b0.js";import{a as j}from"./index.49e953af.js";import{A as g}from"./index.4598445f.js";import{A as q,B as z,a as F,c as H}from"./index.b50eb903.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[r]="5b5b6373-68c3-4fff-bacd-9255ed6be0bd",a._sentryDebugIdIdentifier="sentry-dbid-5b5b6373-68c3-4fff-bacd-9255ed6be0bd")}catch{}})();const M={},v=a=>(I("data-v-439be421"),a=a(),w(),a),U={class:"logo"},Z=v(()=>h("img",{class:"logo-img",src:B,alt:"Abstra cloud logo"},null,-1)),G=v(()=>h("span",null,"Abstra Cloud",-1)),J=[Z,G];function K(a,r){return s(),y("div",U,J)}const O=C(M,[["render",K],["__scopeId","data-v-439be421"]]),Q=k({__name:"LoginBlock",setup(a){function r(p){const f=p.split("@")[0];return T.exports.kebabCase(f).toUpperCase().split("-").slice(0,2).map(i=>i[0]).join("")}const l=L(),{result:n,loading:u,refetch:x}=$(async()=>b.getAuthor());function A(){b.removeAuthor(),x(),l.push({name:"login"})}return(p,f)=>{const i=N("router-link");return e(u)?(s(),c(e(D),{key:0})):e(n)?(s(),c(e(S),{key:1,placement:"bottomRight"},{content:t(()=>[o(e(g),{direction:"vertical"},{default:t(()=>[o(e(j),null,{default:t(()=>[d(_(e(n).claims.email),1)]),_:1}),o(e(m),{onClick:A},{default:t(()=>[d("Logout")]),_:1})]),_:1})]),default:t(()=>[o(e(g),{align:"center",style:{cursor:"pointer"}},{default:t(()=>[o(e(q),null,{default:t(()=>[d(_(r(e(n).claims.email)),1)]),_:1})]),_:1})]),_:1})):(s(),c(e(m),{key:2},{default:t(()=>[o(i,{to:"/login"},{default:t(()=>[d("Login")]),_:1})]),_:1}))}}}),re=k({__name:"Navbar",props:{breadcrumb:{}},setup(a){return(r,l)=>(s(),c(e(H),{style:{padding:"5px 10px"}},{breadcrumb:t(()=>[r.breadcrumb?(s(),c(e(z),{key:0},{default:t(()=>[(s(!0),y(R,null,V(r.breadcrumb,(n,u)=>(s(),c(e(F),{key:u},{default:t(()=>[o(e(E),{to:n.path},{default:t(()=>[d(_(n.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):P("",!0)]),title:t(()=>[o(O)]),extra:t(()=>[o(Q)]),_:1}))}});export{re as _};
//# sourceMappingURL=Navbar.vue_vue_type_script_setup_true_lang.debcdf1c.js.map
