import{x as a,a as o,b as i,c,g as d,h as p,_,i as u,T as l,j as h,P as b,C as f,M as m,s as y,k as s,l as g,m as v,n as w,p as I}from"./outputWidgets.75a5b0b9.js";import{u as k}from"./index.7a91ca2c.js";import"./pubsub.3fa240d3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="3bcea365-b878-42d6-98da-3b5a37b0cc03",e._sentryDebugIdIdentifier="sentry-dbid-3bcea365-b878-42d6-98da-3b5a37b0cc03")}catch{}})();const x={};function A(e,t){const r=o("router-view");return i(),c(r,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const D=a(x,[["render",A]]),n=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.753d0084.js"),["assets/Player.753d0084.js","assets/index.a1ee75ca.js","assets/outputWidgets.75a5b0b9.js","assets/outputWidgets.8ce475af.css","assets/uuid.6680d6a1.js","assets/broker.6112f7bc.js","assets/index.7a91ca2c.js","assets/pubsub.3fa240d3.js","assets/executeJs.fb1c318e.js","assets/icons.c04528be.js","assets/CircularLoading.1b6701b1.js","assets/CircularLoading.f81b57b4.css","assets/PlayerNavbar.04a45a2a.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.abab7b0a.js","assets/Steps.998aa76d.css","assets/Modal.21246413.js","assets/Modal.5aaf8eba.css","assets/executeJs.dfa3b35d.css","assets/WidgetsFrame.fd4386d8.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.acb7988b.js","assets/broker.ac4594bd.css","assets/DashPlayer.947616d9.js","assets/geometryUtils.6b829608.js","assets/DashPlayer.4868beea.css","assets/asyncComputed.c701d7b0.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class P{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}(async()=>{await k();const e=u({render:()=>g(D)});l.init(),h(e,n),P.init(),e.use(n),e.use(b),e.mount("#app"),e.component("VSelect",f),e.component("Markdown",m),e.component("Message",y),s(e,v),s(e,w),s(e,I)})();
//# sourceMappingURL=player.e73442de.js.map
