import{S as p}from"./Sidebar.9797edfe.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.debcdf1c.js";import{G as d,H as l,I as b}from"./icons.c04528be.js";import{d as u,eA as f,J as g,a as _,b as y,c as v,w as a,f as e}from"./outputWidgets.75a5b0b9.js";import{a as w}from"./asyncComputed.c701d7b0.js";import"./console.3fb52eaf.js";import{O as z}from"./organization.98baeec7.js";import"./index.a131125e.js";import{B as h}from"./BaseLayout.324568a0.js";import"./Tooltip.b03bfe8e.js";import"./logo.084e5d7c.js";import"./index.49e953af.js";import"./Title.b6c9692d.js";import"./index.4598445f.js";import"./index.b50eb903.js";import"./index.a1ee75ca.js";import"./Form.2c716183.js";import"./index.b6767512.js";import"./dayjs.d3366d83.js";import"./index.e24c456b.js";import"./index.7aacb57f.js";import"./TabPane.0d7849ee.js";import"./index.e9ba5796.js";import"./CollapsePanel.46ee4c6b.js";import"./index.3916405f.js";import"./index.5a67eb5f.js";import"./index.fe803cdf.js";import"./index.5e9c5434.js";import"./index.00d295c9.js";import"./index.fc88890c.js";import"./index.9c0809a0.js";import"./gateway.99e43695.js";import"./activeRecord.115270b9.js";import"./pubsub.3fa240d3.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="69742ffa-5d1b-4afd-abfb-1cc45fc6b20d",o._sentryDebugIdIdentifier="sentry-dbid-69742ffa-5d1b-4afd-abfb-1cc45fc6b20d")}catch{}})();const io=u({__name:"Organization",setup(o){const i=f().params.organizationId,{result:r}=w(()=>z.get(i)),n=g(()=>r.value?[{label:"My organizations",path:"/organizations"},{label:r.value.name,path:`/organizations/${r.value.id}`}]:void 0),m=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:b,path:"billing",unavailable:!0}]}];return(I,B)=>{const s=_("router-view");return y(),v(h,null,{navbar:a(()=>[e(c,{breadcrumb:n.value},null,8,["breadcrumb"])]),sidebar:a(()=>[e(p,{class:"sidebar",sections:m})]),content:a(()=>[e(s)]),_:1})}}});export{io as default};
//# sourceMappingURL=Organization.8c8bc3fd.js.map
