var P=Object.defineProperty;var C=(a,e,t)=>e in a?P(a,e,{enumerable:!0,configurable:!0,writable:!0,value:t}):a[e]=t;var u=(a,e,t)=>(C(a,typeof e!="symbol"?e+"":e,t),t);import{d as _,r as k,eA as x,J as D,b as $,et as j,f as l,u as d,w as p,bq as N,aT as w,eC as T}from"./outputWidgets.75a5b0b9.js";import{a as M}from"./asyncComputed.c701d7b0.js";import{P as E}from"./project.f661f5a0.js";import"./console.3fb52eaf.js";import{M as B}from"./member.4f43bd8b.js";import{C as y}from"./gateway.99e43695.js";import{A as q}from"./activeRecord.115270b9.js";import"./index.a131125e.js";import{q as K}from"./icons.c04528be.js";import{_ as R}from"./CrudView.vue_vue_type_script_setup_true_lang.ff628288.js";import{f as S}from"./index.b048d0fb.js";import{A as U,a as V}from"./index.49e953af.js";import{M as z}from"./Title.b6c9692d.js";import"./index.a1ee75ca.js";import"./Form.2c716183.js";import"./index.b50eb903.js";import"./index.4598445f.js";import"./index.b6767512.js";import"./dayjs.d3366d83.js";import"./index.e24c456b.js";import"./index.7aacb57f.js";import"./TabPane.0d7849ee.js";import"./index.e9ba5796.js";import"./CollapsePanel.46ee4c6b.js";import"./index.3916405f.js";import"./index.5a67eb5f.js";import"./index.fe803cdf.js";import"./index.5e9c5434.js";import"./index.00d295c9.js";import"./index.fc88890c.js";import"./index.9c0809a0.js";import"./pubsub.3fa240d3.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="9598ca6a-bf68-4682-adf9-93634accb7ba",a._sentryDebugIdIdentifier="sentry-dbid-9598ca6a-bf68-4682-adf9-93634accb7ba")}catch{}})();class F{constructor(){u(this,"urlPath","api-keys")}async create({projectId:e,name:t}){return y.post(`projects/${e}/${this.urlPath}`,{name:t})}async delete(e,t){await y.delete(`projects/${e}/${this.urlPath}/${t}`)}async list(e){return y.get(`projects/${e}/${this.urlPath}`)}async get(){throw new Error("Not implemented")}async update(){throw new Error("Not implemented")}}const m=new F;class s{constructor(e){u(this,"record");this.record=q.create(m,e,"id")}static async list(e){return(await m.list(e)).map(f=>new s(f))}static async create(e){const t=await m.create(e);return new s(t)}static async delete(e,t){await m.delete(e,t)}get id(){return this.record.get("id")}get name(){return this.record.get("name")}async save(){await this.record.save()}get createdAt(){return new Date(this.record.get("createdAt"))}hasChanges(){return this.record.hasChanges()}get ownerId(){return this.record.get("createdBy")}get value(){var e;return(e=this.record.get("value"))!=null?e:null}}const Pe=_({__name:"ApiKeys",setup(a){const e=k(null),t=[{key:"name",label:"API key name"}],c=x().params.projectId,{loading:A,result:I,refetch:g}=M(async()=>Promise.all([s.list(c),E.get(c).then(r=>B.list(r.organizationId))]).then(([r,o])=>r.map(n=>({apiKey:n,member:o.find(i=>i.authorId===n.ownerId)})))),b=async r=>{const o=await s.create({projectId:c,name:r.name});g(),e.value=o.value},v=D(()=>{var r,o;return{columns:[{name:"Name"},{name:"Creation date"},{name:"Owner"},{name:"Actions",align:"right"}],rows:(o=(r=I.value)==null?void 0:r.map(({apiKey:n,member:i})=>{var h;return{key:n.id,cells:[{text:n.name},{text:S(n.createdAt,Date.now(),{addSuffix:!0})},{text:(h=i==null?void 0:i.email)!=null?h:"Unknown"},{text:"actions",actions:[{label:"Delete",icon:K,dangerous:!0,onClick:async()=>{await s.delete(c,n.id),g()}}]}]}}))!=null?o:[]}});return(r,o)=>($(),j(N,null,[l(R,{"entity-name":"API key","create-button-text":"Create API Key",loading:d(A),title:"API Keys",description:"API Keys are used to deploy your app from the local editor.","empty-title":"No API keys here yet",table:v.value,fields:t,onCreate:b},null,8,["loading","table"]),l(d(z),{open:!!e.value,title:"Api key generated",onCancel:o[0]||(o[0]=n=>e.value=null)},{footer:p(()=>[]),default:p(()=>[l(d(U),null,{default:p(()=>[w("Your API key was successfully generated. Use this code to login on your local development environment or deploy using CI")]),_:1}),l(d(V),{code:"",copyable:""},{default:p(()=>[w(T(e.value),1)]),_:1})]),_:1},8,["open"])],64))}});export{Pe as default};
//# sourceMappingURL=ApiKeys.88d7b64d.js.map
