import{v as s}from"./icons.c04528be.js";import{d as r,a as c,b as i,et as d,f,u as _,aT as l,x as u}from"./outputWidgets.75a5b0b9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="4a992ff9-11e3-4756-a891-e21150fe5a0a",e._sentryDebugIdIdentifier="sentry-dbid-4a992ff9-11e3-4756-a891-e21150fe5a0a")}catch{}})();const p=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(a,n)=>{const o=c("icon");return i(),d("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[f(o,{class:"icon",path:_(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),l(" Editor ")])}}});const v=u(p,[["__scopeId","data-v-eaeb3a6e"]]);export{v as B};
//# sourceMappingURL=BackButton.05afbac7.js.map
