import{d as y,ez as g,eA as v,r as b,b as r,c as a,w as s,u as e,f as c,ew as n}from"./outputWidgets.75a5b0b9.js";import{S as h,L as w}from"./SmartConsole.c35b14e7.js";import{a as B}from"./asyncComputed.c701d7b0.js";import{H as C}from"./hooks.1c8a8ebc.js";import{_ as H}from"./SaveButton.vue_vue_type_script_setup_true_lang.d3cd006c.js";import{_ as I}from"./DocsButton.vue_vue_type_script_setup_true_lang.0e30e393.js";import{B as S}from"./BaseLayout.324568a0.js";import{_ as T,a as x}from"./HookSettings.vue_vue_type_script_setup_true_lang.f4eeb436.js";import{c as A}from"./index.b50eb903.js";import{A as k,T as D}from"./TabPane.0d7849ee.js";import"./forms.d6fd4b56.js";import"./activeRecord.115270b9.js";import"./pubsub.3fa240d3.js";import"./dashes.cbc2452d.js";import"./index.a1ee75ca.js";import"./jobs.4af0de33.js";import"./workspaces.f47922e6.js";import"./icons.c04528be.js";import"./Title.b6c9692d.js";import"./index.9c0809a0.js";import"./uuid.6680d6a1.js";import"./ant-design.7c6678de.js";import"./StageRunSelector.vue_vue_type_script_setup_true_lang.4674e54d.js";import"./index.fe803cdf.js";import"./index.5e9c5434.js";import"./CollapsePanel.46ee4c6b.js";import"./index.4598445f.js";import"./index.e24c456b.js";import"./Form.2c716183.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[m]="5a0bcbfb-5f90-465f-b28a-87acb87bc157",i._sentryDebugIdIdentifier="sentry-dbid-5a0bcbfb-5f90-465f-b28a-87acb87bc157")}catch{}})();const me=y({__name:"HookEditor",setup(i){const m=g(),f=v(),l=b(null),o=b("test");function _(){m.push({name:"hooks"})}const{result:t}=B(()=>C.get(f.params.hookPath)),p=w.create();return(R,d)=>(r(),a(S,null,{navbar:s(()=>[e(t)?(r(),a(e(A),{key:0,title:e(t).title,onBack:_},{footer:s(()=>[c(e(D),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=u=>o.value=u)},{default:s(()=>[c(e(k),{key:"test",tab:"Test"}),c(e(k),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:s(()=>[c(I,{path:"hooks"}),o.value==="settings"?(r(),a(H,{key:0,model:e(t)},null,8,["model"])):n("",!0)]),_:1},8,["title"])):n("",!0)]),content:s(()=>[e(t)&&o.value==="test"?(r(),a(T,{key:0,ref_key:"tester",ref:l,hook:e(t),"log-service":e(p)},null,8,["hook","log-service"])):n("",!0),e(t)&&o.value==="settings"?(r(),a(x,{key:1,hook:e(t)},null,8,["hook"])):n("",!0)]),footer:s(()=>{var u;return[e(t)&&o.value==="test"?(r(),a(h,{key:0,runtime:"forms","log-service":e(p),onRestart:(u=l.value)==null?void 0:u.runHook},null,8,["log-service","onRestart"])):n("",!0)]}),_:1}))}});export{me as default};
//# sourceMappingURL=HookEditor.c7da6c95.js.map
