import{x as t,b as d,et as s}from"./outputWidgets.75a5b0b9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="b2e0ada7-e74d-450b-bdc9-4738b2bd262d",e._sentryDebugIdIdentifier="sentry-dbid-b2e0ada7-e74d-450b-bdc9-4738b2bd262d")}catch{}})();const o={},r={class:"organization-settings"};function a(e,n){return d(),s("div",r,"Organization settings")}const b=t(o,[["render",a]]);export{b as default};
//# sourceMappingURL=OrganizationSettings.f0e28b47.js.map
