import{C as t}from"./Title.b6c9692d.js";import{F as n}from"./outputWidgets.75a5b0b9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="4e99fc75-d38d-4ea5-ad50-4a2c810f19c1",e._sentryDebugIdIdentifier="sentry-dbid-4e99fc75-d38d-4ea5-ad50-4a2c810f19c1")}catch{}})();const s=n(t);export{s as A};
//# sourceMappingURL=index.5a67eb5f.js.map
