import{R as d}from"./Title.b6c9692d.js";import{F as n}from"./outputWidgets.75a5b0b9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="b04fda0d-a98b-4caa-9660-4e9b090489e7",e._sentryDebugIdIdentifier="sentry-dbid-b04fda0d-a98b-4caa-9660-4e9b090489e7")}catch{}})();const s=n(d);export{s as A};
//# sourceMappingURL=index.9c0809a0.js.map
