import{d as u,eA as b,J as c,a as g,b as f,c as v,w as i,f as s}from"./outputWidgets.75a5b0b9.js";import{B as _}from"./BaseLayout.324568a0.js";import{a as h}from"./asyncComputed.c701d7b0.js";import{P as y}from"./project.f661f5a0.js";import"./console.3fb52eaf.js";import{O as z}from"./organization.98baeec7.js";import"./index.a131125e.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.debcdf1c.js";import{S as I}from"./Sidebar.9797edfe.js";import{k as w,J as k,K as B,L as P,M as $,N as C,O as M,G as x,H as D,I as L}from"./icons.c04528be.js";import"./gateway.99e43695.js";import"./activeRecord.115270b9.js";import"./pubsub.3fa240d3.js";import"./index.a1ee75ca.js";import"./Form.2c716183.js";import"./Title.b6c9692d.js";import"./index.b50eb903.js";import"./index.4598445f.js";import"./index.b6767512.js";import"./dayjs.d3366d83.js";import"./index.e24c456b.js";import"./index.7aacb57f.js";import"./TabPane.0d7849ee.js";import"./index.e9ba5796.js";import"./CollapsePanel.46ee4c6b.js";import"./index.3916405f.js";import"./index.5a67eb5f.js";import"./index.fe803cdf.js";import"./index.5e9c5434.js";import"./index.00d295c9.js";import"./index.fc88890c.js";import"./index.9c0809a0.js";import"./index.49e953af.js";import"./logo.084e5d7c.js";import"./Tooltip.b03bfe8e.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="897dea8d-8bf9-4cad-a308-89261a090e6e",t._sentryDebugIdIdentifier="sentry-dbid-897dea8d-8bf9-4cad-a308-89261a090e6e")}catch{}})();const ga=u({__name:"Project",setup(t){const p=b().params.projectId,{result:a}=h(()=>y.get(p).then(async o=>{const e=await z.get(o.organizationId);return{project:o,organization:e}})),l=c(()=>{var o,e,r,m;return((o=a.value)==null?void 0:o.organization)&&a.value.project?[{label:"My organizations",path:"/organizations"},{label:(r=(e=a.value)==null?void 0:e.organization)==null?void 0:r.name,path:`/organizations/${(m=a.value)==null?void 0:m.organization.id}`},{label:a.value.project.name,path:`/projects/${a.value.project.id}`}]:void 0}),d=c(()=>{var o;return(o=a.value)!=null&&o.project?[{name:"Project",items:[{name:"Builds",path:"builds",icon:w},{name:"Connectors",path:"connectors",icon:k},{name:"Tables",path:"tables",icon:B},{name:"API Keys",path:"api-keys",icon:P},{name:"Env Vars",path:"env-vars",icon:$},{name:"Logs",icon:C,path:"logs",beta:!0},{name:"Settings",icon:M,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:x,path:`/organizations/${a.value.project.organizationId}/projects`},{name:"Members",icon:D,path:`/organizations/${a.value.project.organizationId}/members`},{name:"Billing",icon:L,path:`/organizations/${a.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(o,e)=>{const r=g("router-view");return f(),v(_,null,{content:i(()=>[s(r)]),navbar:i(()=>[s(j,{class:"nav",breadcrumb:l.value},null,8,["breadcrumb"])]),sidebar:i(()=>[s(I,{class:"sidebar",sections:d.value},null,8,["sections"])]),_:1})}}});export{ga as default};
//# sourceMappingURL=Project.f8756900.js.map
